############################################################################################
############################################################################################

rm(list=ls())
setwd("~/Desktop/appendix")

###### Packages
library(readxl)
library(psych)
library(tidyr)
library(dplyr)
library(rstatix)
library(lsmeans)

###############################################
###### contents

### Study I - Lent
  # data
  # socio-demographic data
  # conditions
  # scales
  # statistical analysis
  # covid-19 impact

### Study II - Autumn
  # data
  # socio-demographic data
  # conditions
  # scales
  # statistical analysis
  # covid-19 impact

############################################################################################
############################################################################################
###                                                                                      ###
###                                   Study I - Lent                                     ###
###                                                                                      ###
############################################################################################
############################################################################################

###############################################
###### data

Lent_t1 <- read_excel("fasting plastic data.xlsx", na="NA", sheet="Data_Lent_t1")
Lent_t2 <- read_excel("fasting plastic data.xlsx", na="NA", sheet="Data_Lent_t2")

### subsets for each group
  # role model condition
Lent_t1_role <- subset(Lent_t1,Lent_t1$Lgroup==1)
Lent_t2_role <- subset(Lent_t2,Lent_t2$Lgroup==1)
  # problem only condition
Lent_t1_prob <- subset(Lent_t1,Lent_t1$Lgroup==2)
Lent_t2_prob <- subset(Lent_t2,Lent_t2$Lgroup==2)

### restructure data for anova
Lent_all <- merge(Lent_t1, Lent_t2, by=c("Lcase", "Lgroup"))
Lent_long_pl <- gather(Lent_all[c("Lcase", "Lgroup", "Lpl1", "Lpl2")], time, value, 'Lpl1':'Lpl2')
rm(Lent_all)

Lent_long_pl$Lgroup <- factor(Lent_long_pl$Lgroup)
Lent_long_pl$time <- factor(Lent_long_pl$time)
Lent_long_pl$Lcase <- factor(Lent_long_pl$Lcase)

Lent_long_pl$value[Lent_long_pl$value == 'NaN'] <- NA
Lent_long_pl <- Lent_long_pl[complete.cases(Lent_long_pl[ , 4]),]

###############################################
###### socio-demographic data

### age (Lage1)
  # 1 = < 18 years old
  # 2 = 18-29 years old
  # 3 = 30 - 49 years old
  # 4 = 50 - 69 years old
  # 5 = > 69 years old

table(Lent_t1$Lage1)
prop.table(table(Lent_t1$Lage1))
  # 13% 18-29 years old; 40% 30 - 49 years old; 46% 50 - 69 years old

### gender (Lsex1)
  # 1 = male
  # 2 = female
  # 3 = diverse

table(Lent_t1$Lsex1)
prop.table(table(Lent_t1$Lsex1))
  # 49% male; 50% female; 0,2% diverse

### education (Ledu1)
  # 1 = no graduation
  # 2 = “Hauptschulabschluss” (secondary school leaving certificate after nine ore ten years. The lowest degree in Germany)
  # 3 = “Mittlere Reife” (secondary school leaving certificate after ten years. Between “Hauptschulabschluss and “Hochschulreife”)
  # 4 = „(Fach-)Hochschulreife“ (high school leaving certificate. Enable to study at university)
  # 5 = university degree

table(Lent_t1$Ledu1)
prop.table(table(Lent_t1$Ledu1))
  # 0,5% no graduation; 13% Hauptschulabschluss; 36% Mittlere Reife,
  # 23% (Fach-)Hochschulreife, 27% university degree

# place of residence (Lloc1)
  # 1 = rural area
  # 2 = town
  # 3 = large city

table(Lent_t1$Lloc1)
prop.table(table(Lent_t1$Lloc1))
  # 30% rural area; 33% town; 38% large city


###############################################
###### conditions

# condition (Lgroup)
  # 1 = role model condition
  # 2 = problem only condition

table(Lent_t1$Lgroup)
  # problem only condition: N=328
  # role model condition: N=328

###############################################
###### scales

### Plastic consumption behavior (t1: Lpl11-Lpl17; aggregated (mean): Lpl1 | t2: Lpl21-Lpl27; aggregated (mean): Lpl2)
  # 1 = nothing was wrapped in plastic
  # 2 = only a few was wrapped in plastic
  # 3 = about the half was wrapped in plastic
  # 4 = the most was wrapped in plastic
  # 5 = all was wrapped in plastic

# cronbach's alpha
alpha(Lent_t1[c("Lpl11", "Lpl12", "Lpl13", "Lpl14", "Lpl15", "Lpl16", "Lpl17")])
  # t1: a=0.71
alpha(Lent_t2[c("Lpl21", "Lpl22", "Lpl23", "Lpl24", "Lpl25", "Lpl26", "Lpl27")])
  # t2: a=0.78

# overall description
describe(Lent_t1$Lpl1)
  # t1: M=3.3, SD=0.8
describe(Lent_t2$Lpl2)
  # t2: M=3.09, SD=0.86

# role model condition
describe(Lent_t1_role$Lpl1)
  # t1: M=3.3, SD=0.8
describe(Lent_t2_role$Lpl2)
  # t2: M=3.08, SD=0.81

# problem only condition
describe(Lent_t1_prob$Lpl1)
  # t1: M=3.31, SD=0.81
describe(Lent_t2_prob$Lpl2)
  # t2: M=3.1, SD=0.9


### Self-efficacy (Lef11-Lef12; aggregated (mean): Lef1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# cronbach's alpha
alpha(Lent_t1[c("Lef11", "Lef12")])
  # t1: a=0.93

# overall description
describe(Lent_t1$Lef1)
  # t1: M=4.06, SD=0.87

# role model condition
describe(Lent_t1_role$Lef1)
  # t1: M=4.12, SD=0.81

# problem only condition
describe(Lent_t1_prob$Lef1)
  # t1: M=4.01, SD=0.93


### Collective efficacy (Lcf11-Lcf12; aggregated (mean): Lcf1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# cronbach's alpha
alpha(Lent_t1[c("Lcf11", "Lcf12")])
  # t1: a=0.83

# overall description
describe(Lent_t1$Lcf1)
  # t1: M=4.29, SD=0.77

# role model condition
describe(Lent_t1_role$Lcf1)
  # t1: M=4.25, SD=0.77

# problem only condition
describe(Lent_t1_prob$Lcf1)
  # t1: M=4.32, SD=0.77


### Intention to avoid plastic (Lin1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# overall description
describe(Lent_t1$Lin1)
  # t1: M=3.06, SD=1.15

# role model condition
describe(Lent_t1_role$Lin1)
  # t1: M=3.08, SD=1.14

# problem only condition
describe(Lent_t1_prob$Lin1)
  # t1: M=3.05, SD=1.17


###############################################
###### statistical analysis

  ###### mixed anova for plastic consumption

### assumptions
  # outlier
Lent_long_pl %>%
  group_by(time, Lgroup) %>%
  identify_outliers(value)
  # -> some outliers, but no extreme

  # normal distribution
shapiro.test(Lent_t1_role$Lpl1) # -> not normal distributed
shapiro.test(Lent_t1_prob$Lpl1) # -> not normal distributed

shapiro.test(Lent_t2_role$Lpl2)
shapiro.test(Lent_t2_prob$Lpl2) # -> not normal distributed

  # homogenity of variances
Lent_long_pl %>%
  group_by(time) %>%
  levene_test(value ~ Lgroup)
  # -> not fulfilled at t1

  # homogenity of covariances
box_m(Lent_long_pl[, "value", drop = FALSE], Lent_long_pl$Lgroup)
  # -> fulfilled

### mixed anova
anova.mixed.pl1 <- anova_test(data = Lent_long_pl, dv = value, wid = Lcase, between = Lgroup,
                              within = time, effect.size = "pes", detailed=T)

get_anova_table(anova.mixed.pl1)
  # Fgroup[1,651]=0.059, p=.81, pes=.00
  # Ftime[1,651]=58.81, p<.001*, pes=.08
  # Fint[1,651]=0.00, p=.97, pes=.00

### post hoc pairwise t-test
comp <- lsmeans(aov(value ~ Lgroup*time + Error(Lcase/time), data=Lent_long_pl),
               specs = ~ Lgroup: time, adjust = "bonferroni")
contrast(comp,method="pairwise")
  # problem only between t1 and t2: Δt1-t2 = 0.21, p < .001
  # role model between t1 and t2: Δt1-t2 = 0.21, p < .001


  ###### t-test for self-efficacy
t.test(Lent_t1_role$Lef1, Lent_t1_prob$Lef1, var.equal = T)
  # t = 1.6344, df = 654, p-value = 0.1027

  ###### t-test for collective efficacy
t.test(Lent_t1_role$Lcf1, Lent_t1_prob$Lcf1, var.equal = T)
  # t = -1.138, df = 654, p-value = 0.2555

  ###### intention to avoid plastic
t.test(Lent_t1_role$Lin1, Lent_t1_prob$Lin1, var.equal = T)
  # t = 0.33868, df = 654, p-value = 0.735


###############################################
###### covid-19 impact

  # (Lcv21-Lcv26)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# more attention to hygiene than usual
table(Lent_t2$Lcv26)
prop.table(table(Lent_t2$Lcv26))
describe(Lent_t2$Lcv26)
  # M=3.55; SD=1.32
  # 13% disagree completely; 8% rather disagree; 18% partly agree and disagree
  # 34% rather agree; 28% agree completely

# the corona virus has disrupted my plans for the Lent
table(Lent_t2$Lcv24)
prop.table(table(Lent_t2$Lcv24))
describe(Lent_t2$Lcv24)
  # M=1.89; SD=1.16
  # 52% disagree completely; 22% rather disagree; 14% partly agree and disagree
  # 7% rather agree; 5% agree completely

# had bought more groceries
table(Lent_t2$Lcv21)
prop.table(table(Lent_t2$Lcv21))
describe(Lent_t2$Lcv21)
  # M=2.38; SD=1.26
  # 32% disagree completely; 27% rather disagree; 17% partly agree and disagree
  # 18% rather agree; 6% agree completely

# more sanitary products
table(Lent_t2$Lcv22)
prop.table(table(Lent_t2$Lcv22))
describe(Lent_t2$Lcv22)
  # M=2.09; SD=1.16
  # 39% disagree completely; 33% rather disagree; 12% partly agree and disagree
  # 12% rather agree; 4% agree completely

# more products in plastic packaging
table(Lent_t2$Lcv23)
prop.table(table(Lent_t2$Lcv23))
describe(Lent_t2$Lcv23)
  # M=2.07; SD=1.14
  # 40% disagree completely; 29% rather disagree; 16% partly agree and disagree
  # 11% rather agree; 4% agree completely

# cooked more often
table(Lent_t2$Lcv25)
prop.table(table(Lent_t2$Lcv25))
describe(Lent_t2$Lcv25)
  # M=2.35; SD=1.29
  # 35% disagree completely; 24% rather disagree; 18% partly agree and disagree
  # 15% rather agree; 7% agree completely


############################################################################################
############################################################################################
###                                                                                      ###
###                                   Study II - Autumn                                  ###
###                                                                                      ###
############################################################################################
############################################################################################

###############################################
###### Data

Autumn_t1 <- read_excel("fasting plastic data.xlsx", na="NA", sheet="Data_Autumn_t1")
Autumn_t2 <- read_excel("fasting plastic data.xlsx", na="NA", sheet="Data_Autumn_t2")

### subsets for each group
  # role model condition
Autumn_t1_role <- subset(Autumn_t1,Autumn_t1$Agroup==1)
Autumn_t2_role <- subset(Autumn_t2,Autumn_t2$Agroup==1)
  # problem only condition
Autumn_t1_prob <- subset(Autumn_t1,Autumn_t1$Agroup==2)
Autumn_t2_prob <- subset(Autumn_t2,Autumn_t2$Agroup==2)
  # no report condition
Autumn_t1_cont <- subset(Autumn_t1,Autumn_t1$Agroup==3)
Autumn_t2_cont <- subset(Autumn_t2,Autumn_t2$Agroup==3)

### restructure data for anova
Autumn_all <- merge(Autumn_t1, Autumn_t2, by=c("Acase", "Agroup"))
Autumn_long_pl <- gather(Autumn_all[c("Acase", "Agroup", "Apl1", "Apl2")], time, value, 'Apl1':'Apl2')
rm(Autumn_all)

Autumn_long_pl$Agroup <- factor(Autumn_long_pl$Agroup)
Autumn_long_pl$time <- factor(Autumn_long_pl$time)
Autumn_long_pl$Acase <- factor(Autumn_long_pl$Acase)

Autumn_long_pl$value[Autumn_long_pl$value == 'NaN'] <- NA
Autumn_long_pl <- Autumn_long_pl[complete.cases(Autumn_long_pl[ , 4]),]

###############################################
###### socio-demographic data

### age (Aage1)
  # 1 = < 18 years old
  # 2 = 18-29 years old
  # 3 = 30 - 49 years old
  # 4 = 50 - 69 years old
  # 5 = > 69 years old

table(Autumn_t1$Aage1)
prop.table(table(Autumn_t1$Aage1))
  # 16% 18-29 years old; 37% 30 - 49 years old; 47% 50 - 69 years old

### gender (Asex1)
  # 1 = male
  # 2 = female
  # 3 = diverse

table(Autumn_t1$Asex1)
prop.table(table(Autumn_t1$Asex1))
  # 48% male; 52% female

### education (Aedu1)
  # 1 = no graduation
  # 2 = “Hauptschulabschluss” (secondary school leaving certificate after nine ore ten years. The lowest degree in Germany)
  # 3 = “Mittlere Reife” (secondary school leaving certificate after ten years. Between “Hauptschulabschluss and “Hochschulreife”)
  # 4 = „(Fach-)Hochschulreife“ (high school leaving certificate. Enable to study at university)
  # 5 = university degree

table(Autumn_t1$Aedu1)
prop.table(table(Autumn_t1$Aedu1))
  # 0,1% no graduation; 12% Hauptschulabschluss; 36% Mittlere Reife,
  # 24% (Fach-)Hochschulreife, 28% university degree

# place of residence (Aloc1)
  # 1 = rural area
  # 2 = town
  # 3 = large city

table(Autumn_t1$Aloc1)
prop.table(table(Autumn_t1$Aloc1))
  # 31% rural area; 34% town; 35% large city


###############################################
###### conditions

# condition (Agroup)
  # 1 = role model condition
  # 2 = problem only condition
  # 3 = no report condition

table(Autumn_t1$Agroup)
  # role model condition: N=329
  # problem only condition: N=314
  # no report condition: N=304

###############################################
###### scales

### Plastic consumption behavior (t1: Apl11-Apl17; aggregated (mean): Apl1 | t2: Apl21-Apl27; aggregated (mean): Apl2)
  # 1 = nothing was wrapped in plastic
  # 2 = only a few was wrapped in plastic
  # 3 = about the half was wrapped in plastic
  # 4 = the most was wrapped in plastic
  # 5 = all was wrapped in plastic

# cronbach's alpha
alpha(Autumn_t1[c("Apl11", "Apl12", "Apl13", "Apl14", "Apl15", "Apl16", "Apl17")])
  # t1: a=0.7
alpha(Autumn_t2[c("Apl21", "Apl22", "Apl23", "Apl24", "Apl25", "Apl26", "Apl27")])
  # t2: a=0.69

# overall description
describe(Autumn_t1$Apl1)
  # t1: M=3.34, SD=0.78
describe(Autumn_t2$Apl2)
  # t2: M=3.41, SD=0.77

# role model condition
describe(Autumn_t1_role$Apl1)
  # t1: M=3.34, SD=0.75
describe(Autumn_t2_role$Apl2)
  # t2: M=3.45, SD=0.76

# problem only condition
describe(Autumn_t1_prob$Apl1)
  # t1: M=3.4, SD=0.79
describe(Autumn_t2_prob$Apl2)
  # t2: M=3.44, SD=0.78

# no report condition
describe(Autumn_t1_cont$Apl1)
  # t1: M=3.28, SD=0.8
describe(Autumn_t2_cont$Apl2)
  # t2: M=3.34, SD=0.78

### Self-efficacy (Aef11-Aef12; aggregated (mean): Aef1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# cronbach's alpha
alpha(Autumn_t1[c("Aef11", "Aef12")])
  # t1: a=0.92

# overall description
describe(Autumn_t1$Aef1)
  # t1: M=4.04, SD=0.87

# role model condition
describe(Autumn_t1_role$Aef1)
  # t1: M=4.05, SD=0.86

# problem only condition
describe(Autumn_t1_prob$Aef1)
  # t1: M=4.1, SD=0.86

# no report condition
describe(Autumn_t1_cont$Aef1)
  # t1: M=3.96, SD=0.87

### Collective efficacy (Acf11-Acf12; aggregated (mean): Acf1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# cronbach's alpha
alpha(Autumn_t1[c("Acf11", "Acf12")])
  # t1: a=0.87

# overall description
describe(Autumn_t1$Acf1)
  # t1: M=4.26, SD=0.86

# role model condition
describe(Autumn_t1_role$Acf1)
  # t1: M=4.25, SD=0.87

# problem only condition
describe(Autumn_t1_prob$Acf1)
  # t1: M=4.35, SD=0.82

# no report condition
describe(Autumn_t1_cont$Acf1)
  # t1: M=4.19, SD=0.88

### Intention to avoid plastic (Ain1)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# overall description
describe(Autumn_t1$Ain1)
  # t1: M=3.02, SD=1.06

# role model condition
describe(Autumn_t1_role$Ain1)
  # t1: M=3.05, SD=1.07

# problem only condition
describe(Autumn_t1_prob$Ain1)
  # t1: - missing values

# no report condition
describe(Autumn_t1_cont$Ain1)
  # t1: M=2.97, SD=1.06


###############################################
###### statistical analysis

  ###### mixed anova for plastic consumption

### assumptions
  # outlier
Autumn_long_pl %>%
  group_by(time, Agroup) %>%
  identify_outliers(value)
  # -> some outliers, but no extreme

  # normal distribution
shapiro.test(Autumn_t1_role$Apl1) # -> not normal distributed
shapiro.test(Autumn_t1_prob$Apl1) # -> not normal distributed
shapiro.test(Autumn_t1_cont$Apl1) # -> not normal distributed

shapiro.test(Autumn_t2_role$Apl2) # -> not normal distributed
shapiro.test(Autumn_t2_prob$Apl2) # -> not normal distributed
shapiro.test(Autumn_t2_cont$Apl2) # -> not normal distributed

  # homogenity of variances
Autumn_long_pl %>%
  group_by(time) %>%
  levene_test(value ~ Agroup)
  # -> fulfilled

  # homogenity of covariances
box_m(Autumn_long_pl[, "value", drop = FALSE], Autumn_long_pl$Agroup)
  # -> fulfilled  

### mixed anova
anova.mixed.pl2 <- anova_test(data = Autumn_long_pl, dv = value, wid = Acase, between = Agroup,
                              within = time, effect.size = "pes", detailed=T)
get_anova_table(anova.mixed.pl2)
  # Fgroup[2,940]=2.07, p=.13
  # Ftime[1,940]=8.81, p=.003*
  # Fint[2,940]=0.77, p=.46

### post hoc pairwise t-test
comp2 <- lsmeans(aov(value ~ Agroup*time + Error(Acase/time), data=Autumn_long_pl),
               specs = ~ Agroup: time, adjust = "bonferroni")
contrast(comp2,method="pairwise")
  # problem only between t1 and t2: Δt1-t2 = -0.05, p = .84
  # role model between t1 and t2: Δt1-t2 = -0.10, p = .06
  # no report condition between t1 and t2: Δt1-t2 = -0.05, p = .83


  ###### one-way anova for self-efficacy

### assumptions
  # outlier
Autumn_t1[, c("Agroup", "Aef1")] %>%
  group_by(Agroup) %>%
  identify_outliers(Aef1)
  # -> some outliers, but no extreme

  # normal distribution
shapiro.test(Autumn_t1_role$Aef1) # -> not normal distributed
shapiro.test(Autumn_t1_prob$Aef1) # -> not normal distributed
shapiro.test(Autumn_t1_cont$Aef1) # -> not normal distributed

  # homogenity of variances
Autumn_t1 %>% levene_test(Aef1 ~ as.factor(Agroup))
  # -> fulfilled

### anova
se_aov <- aov(Autumn_t1$Aef1 ~ Autumn_t1$Agroup)
summary(se_aov)
  # F(1,945) = 1.38, p = .24

### post hoc pairwise t-test
pairwise.t.test(Autumn_t1$Aef1, Autumn_t1$Agroup, p.adj = "bonf")
  # no significance


  ###### one-way anova for collective efficacy
### assumptions
  # outlier
Autumn_t1[, c("Agroup", "Acf1")] %>%
  group_by(Agroup) %>%
  identify_outliers(Acf1)
  # -> some outliers, but no extreme

  # normal distribution
shapiro.test(Autumn_t1_role$Acf1) # -> not normal distributed
shapiro.test(Autumn_t1_prob$Acf1) # -> not normal distributed
shapiro.test(Autumn_t1_cont$Acf1) # -> not normal distributed

  # homogenity of variances
Autumn_t1 %>% levene_test(Acf1 ~ as.factor(Agroup))
  # -> fulfilled

### anova
ce_aov <- aov(Autumn_t1$Acf1 ~ Autumn_t1$Agroup)
summary(ce_aov)
  # F(1,945) = 0.58, p = .45

### post hoc pairwise t-test
pairwise.t.test(Autumn_t1$Acf1, Autumn_t1$Agroup, p.adj = "bonf")
  # no significance

  ###### t-test for intention to avoid plastic
t.test(Autumn_t1_role$Ain1, Autumn_t1_cont$Ain1, var.equal = T)
  # t = 0.95694, df = 631, p-value = 0.339


###############################################
###### covid-19 impact

  # (Acv21-Acv26)
  # 1 = disagree completely
  # 2 = rather disagree
  # 3 = partly agree and disagree
  # 4 = rather agree
  # 5 = agree completely

# more attention to hygiene than usual
table(Autumn_t2$Acv26)
prop.table(table(Autumn_t2$Acv26))
describe(Autumn_t2$Acv26)
  # M=3.15; SD=1.29
  # 16% disagree completely; 14% rather disagree; 24% partly agree and disagree
  # 31% rather agree; 15% agree completely

# more products in plastic packaging
table(Autumn_t2$Acv23)
prop.table(table(Autumn_t2$Acv23))
describe(Autumn_t2$Acv23)
  # M=1.98; SD=1.06
  # 41% disagree completely; 33% rather disagree; 15% partly agree and disagree
  # 8% rather agree; 3% agree completely

# bought more groceries
table(Autumn_t2$Acv21)
prop.table(table(Autumn_t2$Acv21))
describe(Autumn_t2$Acv21)
  # M=2.09; SD=1.12
  # 36% disagree completely; 37% rather disagree; 11% partly agree and disagree
  # 12% rather agree; 3% agree completely

# more sanitary products
table(Autumn_t2$Acv22)
prop.table(table(Autumn_t2$Acv22))
describe(Autumn_t2$Acv22)
  # M=2.19; SD=1.17
  # 35% disagree completely; 32% rather disagree; 15% partly agree and disagree
  # 14% rather agree; 4% agree completely

# cooked more often
table(Autumn_t2$Acv25)
prop.table(table(Autumn_t2$Acv25))
describe(Autumn_t2$Acv25)
  # M=2.74; SD=1.37
  # 27% disagree completely; 19% rather disagree; 21% partly agree and disagree
  # 22% rather agree; 12% sagree completely


############################################################################################
############################################################################################